==> eam-wshub-proxyclient-11.4-0-sources.jar: net/datastream/schemas/mp_results/mp0614_001/MP0614_DeletePartsAssociated_001_Result.java <==

package net.datastream.schemas.mp_results.mp0614_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.PARTASSOCIATEDID_Type;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PARTASSOCIATEDID"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "partassociatedid"
})
@XmlRootElement(name = "MP0614_DeletePartsAssociated_001_Result")
public class MP0614_DeletePartsAssociated_001_Result {

    @XmlElement(name = "PARTASSOCIATEDID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected PARTASSOCIATEDID_Type partassociatedid;

    /**
     * Gets the value of the partassociatedid property.
     * 
     * @return
     *     possible object is
     *     {@link PARTASSOCIATEDID_Type }
     *     
     */
    public PARTASSOCIATEDID_Type getPARTASSOCIATEDID() {
        return partassociatedid;
    }

    /**
     * Sets the value of the partassociatedid property.
     * 
     * @param value
     *     allowed object is
     *     {@link PARTASSOCIATEDID_Type }
     *     
     */
    public void setPARTASSOCIATEDID(PARTASSOCIATEDID_Type value) {
        this.partassociatedid = value;
    }

}

==> eam-wshub-proxyclient-11.4-12-sources.jar: net/datastream/schemas/mp_results/mp0614_001/MP0614_DeletePartsAssociated_001_Result.java <==

package net.datastream.schemas.mp_results.mp0614_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.PARTASSOCIATEDID_Type;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PARTASSOCIATEDID"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "partassociatedid"
})
@XmlRootElement(name = "MP0614_DeletePartsAssociated_001_Result")
public class MP0614_DeletePartsAssociated_001_Result {

    @XmlElement(name = "PARTASSOCIATEDID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected PARTASSOCIATEDID_Type partassociatedid;

    /**
     * Obtient la valeur de la propriété partassociatedid.
     * 
     * @return
     *     possible object is
     *     {@link PARTASSOCIATEDID_Type }
     *     
     */
    public PARTASSOCIATEDID_Type getPARTASSOCIATEDID() {
        return partassociatedid;
    }

    /**
     * Définit la valeur de la propriété partassociatedid.
     * 
     * @param value
     *     allowed object is
     *     {@link PARTASSOCIATEDID_Type }
     *     
     */
    public void setPARTASSOCIATEDID(PARTASSOCIATEDID_Type value) {
        this.partassociatedid = value;
    }

}
